==> dokuwiki_0.0.20050922.orig.tar.gz: dokuwiki-2005-09-22/inc/lang/pl/lang.php <==
<?php
/**
 * polish language file
 * based on english one
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Grzegorz Żur <grzesiekzur@tlen.pl>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Edytuj stronę';
$lang['btn_source'] = 'Pokaż źródło strony';
$lang['btn_show']   = 'Pokaż stronę';
$lang['btn_create'] = 'Utwórz stronę';
$lang['btn_search'] = 'Szukaj';
$lang['btn_save']   = 'Zapisz';
$lang['btn_preview']= 'Podgląd';
$lang['btn_top']    = 'Do góry';
$lang['btn_newer']  = '<< późniejsze';
$lang['btn_older']  = 'wcześniejsze >>';
$lang['btn_revs']   = 'Poprzednie wersje';
$lang['btn_recent'] = 'Ostatnie zmiany';
$lang['btn_upload'] = 'Wyślij';
$lang['btn_cancel'] = 'Anuluj';
$lang['btn_index']  = 'Indeks';
$lang['btn_secedit']= 'Edytuj';
$lang['btn_login']  = 'Zaloguj';
$lang['btn_logout'] = 'Wyloguj';
$lang['btn_admin']  = 'Administracja';
$lang['btn_update'] = 'Aktualizuj';
$lang['btn_delete'] = 'Usuń';
$lang['btn_back']   = 'Wstecz';
$lang['btn_backlink']    = 'Odnośniki';
$lang['btn_backtomedia'] = 'Powrót do wyboru pliku';
$lang['btn_subscribe']   = 'Subskrybuj zmiany';
$lang['btn_unsubscribe'] = 'Zaprzestań subskrypcji zmian';

$lang['loggedinas'] = 'Zalogowany/a jako';
$lang['user']       = 'Użytkownik';
$lang['pass']       = 'Hasło';
$lang['passchk']    = 'Powtórz hasło';
$lang['remember']   = 'Zapamiętaj';
$lang['fullname']   = 'Imię i nazwisko';
$lang['email']      = 'E-mail';
$lang['register']   = 'Zarejestruj się!';
$lang['badlogin']   = 'Nazwa użytkownika lub hasło są nieprawidłowe.';

$lang['regmissing'] = 'Wypełnij wszystkie pola.';
$lang['reguexists'] = 'Użytkownik o tej nazwie już istnieje.';
$lang['regsuccess'] = 'Utworzono użytkownika. Hasło zostało przesłane pocztą.';
$lang['regsuccess2']= 'Utworzono użytkownika.';
$lang['regmailfail']= 'Wystąpił błąd przy wysyłaniu hasła pocztą!';
$lang['regbadmail'] = 'Adres e-mail jest nieprawidłowy!';
$lang['regbadpass'] = 'Hasła nie są identyczne, spróbuj ponownie.';
$lang['regpwmail']  = 'Twoje hasło do DokuWiki';
$lang['reghere']    = 'Nie masz jeszcze konta? Zdobądź je';

$lang['txt_upload']   = 'Wybierz plik do wysłania';
$lang['txt_filename'] = 'Nazwa pliku (opcjonalnie)';
$lang['txt_overwrt']  = 'Nadpisać istniejący plik?';
$lang['lockedby']     = 'Aktualnie zablokowane przez';
$lang['lockexpire']   = 'Blokada wygasa';
$lang['willexpire']   = 'Za minutę Twoja blokada tej strony wygaśnie.\nW celu uniknięcia konfliktów wyświetl podgląd aby odnowić blokadę.';

$lang['notsavedyet'] = 'Nie zapisane zmiany zostaną utracone.\nCzy na pewno kontynuować?';
$lang['rssfailed']   = 'Wystąpił błąd przy pobieraniu tych danych: ';
$lang['nothingfound']= 'Nic nie znaleziono.';

$lang['mediaselect'] = 'Wysyłanie pliku';
$lang['fileupload']  = 'Wysyłanie pliku';
$lang['uploadsucc']  = 'Wysyłanie powiodło się!';
$lang['uploadfail']  = 'Błąd wysyłania pliku. Czy prawa do katalogów są poprawne?';
$lang['uploadwrong'] = 'Wysyłanie zabronione. Nie można wysłać plików z takim rozszerzeniem';
$lang['uploadexist'] = 'Plik już istnieje, nie wykonano operacji.';
$lang['deletesucc']  = 'Plik "%s" został usunięty.';
$lang['deletefail']  = 'Plik "%s" nie został usunięty, sprawdź uprawnienia.';
$lang['mediainuse']  = 'Plik "%s" nie został usunięty, ponieważ jest używany.';
$lang['namespaces']  = 'Katalogi';
$lang['mediafiles']  = 'Dostępne pliki';

$lang['reference']   = 'Odnośniki do';
$lang['ref_inuse']   = 'Ten plik nie może być usunięty, ponieważ jest używany na następujących stronach:';
$lang['ref_hidden']  = 'Odnośniki mogą znajdować się na stronach, do których nie masz uprawnień.';

$lang['hits']       = 'trafień';
$lang['quickhits']  = 'Pasujące hasła';
$lang['toc']        = 'Spis treści';
$lang['current']    = 'aktualna';
$lang['yours']      = 'Twoja wersja';
$lang['diff']       = 'Pokaż różnicę między wersjami';
$lang['line']       = 'Linia';
$lang['breadcrumb'] = 'Ślad';
$lang['lastmod']    = 'ostatnio zmienione';
$lang['by']         = 'przez';
$lang['deleted']    = 'usunięto';
$lang['created']    = 'utworzono';
$lang['restored']   = 'przywrócono poprzednią wersję';
$lang['summary']    = 'Opis zmian';

$lang['mail_newpage'] = 'Strona dodana:';
$lang['mail_changed'] = 'Strona zmieniona:';

$lang['nosmblinks'] = 'Odnośniki do zasobów sieci Windows działają tylko w przeglądarce Internet Explorer.\n Możesz skopiować odnośnik.';

$lang['qb_alert']   = 'Wpisz tekst, który chcesz sformatować.\nBędzie on dołączony na koniec strony.';
$lang['qb_bold']    = 'Pogrubienie';
$lang['qb_italic']  = 'Pochylenie';
$lang['qb_underl']  = 'Podkreślenie';
$lang['qb_code']    = 'Kod źródłowy';
$lang['qb_strike']  = 'Przekreślenie';
$lang['qb_h1']      = 'Nagłówek 1 stopnia';
$lang['qb_h2']      = 'Nagłówek 2 stopnia';
$lang['qb_h3']      = 'Nagłówek 3 stopnia';
$lang['qb_h4']      = 'Nagłówek 4 stopnia';
$lang['qb_h5']      = 'Nagłówek 5 stopnia';
$lang['qb_link']    = 'Odnośnik wewnętrzny';
$lang['qb_extlink'] = 'Odnośnik zewnętrzny';
$lang['qb_hr']      = 'Linia pozioma';
$lang['qb_ol']      = 'Numeracja';
$lang['qb_ul']      = 'Wypunktowanie';
$lang['qb_media']   = 'Dodaj obrazek lub inny plik';
$lang['qb_sig']     = 'Wstaw podpis';

$lang['del_confirm']= 'Czy napewno usunąć?';

$lang['admin_acl']  = 'Zarządzanie uprawnieniami';
$lang['admin_register']= 'Dodawanie użytkownika';

$lang['acl_group']  = 'Grupa';
$lang['acl_user']   = 'Użytkownik';
$lang['acl_perms']  = 'Uprawnienia użytkownika';
$lang['page']       = 'Strona';
$lang['namespace']  = 'Katalog';

$lang['acl_perm1']  = 'Czytanie';
$lang['acl_perm2']  = 'Zmiana';
$lang['acl_perm4']  = 'Tworzenie';
$lang['acl_perm8']  = 'Przesyłanie plików';
$lang['acl_perm16'] = 'Usuwanie';
$lang['acl_new']    = 'Dodaj nowy wpis';

$lang['spell_start'] = 'Sprawdź pisownię';
$lang['spell_stop']  = 'Zakończ sprawdzanie';
$lang['spell_wait']  = 'Proszę czekać...';
$lang['spell_noerr'] = 'Nie znaleziono błędów';
$lang['spell_nosug'] = 'Brak podpowiedzi';
$lang['spell_change']= 'Zmień';

$lang['metaedit']    = 'Edytuj metadane';
$lang['metasaveerr'] = 'Zapis metadanych nie powiódł się';
$lang['metasaveok']  = 'Metadane zapisano';
$lang['img_backto']  = 'Wróć do';
$lang['img_title']   = 'Tytuł';
$lang['img_caption'] = 'Nagłówek';
$lang['img_date']    = 'Data';
$lang['img_fname']   = 'Nazwa pliku';
$lang['img_fsize']   = 'Rozmiar';
$lang['img_artist']  = 'Fotograf';
$lang['img_copyr']   = 'Prawa autorskie';
$lang['img_format']  = 'Format';
$lang['img_camera']  = 'Aparat';
$lang['img_keywords']= 'Słowa kluczowe';

$lang['subscribe_success']  = 'Dodano %s do listy subskrypcji strony %s';
$lang['subscribe_error']    = 'Błąd przy dodawaniu %s do listy subskrypcji strony %s';
$lang['subscribe_noaddress']= 'Nie podałeś adresu e-mail przy rejestracji, nie możesz zostać dodany do listy subskrypcji.';
$lang['unsubscribe_success']= 'Usunięto %s z listy subskrypcji strony %s';
$lang['unsubscribe_error']  = 'Błąd przu usuwaniu %s z listy subskrypcji strony %s';

//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20060309.orig.tar.gz: dokuwiki-2006-03-09/inc/lang/pl/lang.php <==
<?php
/**
 * polish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Grzegorz Żur <grzegorz.zur@gmail.com>
 *
 *
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Edytuj stronę';
$lang['btn_source'] = 'Pokaż źródło strony';
$lang['btn_show']   = 'Pokaż stronę';
$lang['btn_create'] = 'Utwórz stronę';
$lang['btn_search'] = 'Szukaj';
$lang['btn_save']   = 'Zapisz';
$lang['btn_preview']= 'Podgląd';
$lang['btn_top']    = 'Do góry';
$lang['btn_newer']  = '<< późniejsze';
$lang['btn_older']  = 'wcześniejsze >>';
$lang['btn_revs']   = 'Poprzednie wersje';
$lang['btn_recent'] = 'Ostatnie zmiany';
$lang['btn_upload'] = 'Wyślij';
$lang['btn_cancel'] = 'Anuluj';
$lang['btn_index']  = 'Indeks';
$lang['btn_secedit']= 'Edytuj';
$lang['btn_login']  = 'Zaloguj';
$lang['btn_logout'] = 'Wyloguj';
$lang['btn_admin']  = 'Administracja';
$lang['btn_update'] = 'Aktualizuj';
$lang['btn_delete'] = 'Usuń';
$lang['btn_back']   = 'Wstecz';
$lang['btn_backlink']    = 'Odnośniki';
$lang['btn_backtomedia'] = 'Powrót do wyboru pliku';
$lang['btn_subscribe']   = 'Subskrybuj zmiany';
$lang['btn_unsubscribe'] = 'Zaprzestań subskrypcji zmian';
$lang['btn_profile']    = 'Aktualizuj profil';
$lang['btn_reset']     = 'Resetuj';
$lang['btn_resendpwd'] = 'Prześlij nowe hasło';

$lang['loggedinas'] = 'Zalogowany jako';
$lang['user']       = 'Użytkownik';
$lang['pass']       = 'Hasło';
$lang['newpass']    = 'Nowe hasło';
$lang['oldpass']    = 'Potwierdź aktualne hasło';
$lang['passchk']    = 'Powtórz hasło';
$lang['remember']   = 'Zapamiętaj';
$lang['fullname']   = 'Imię i nazwisko';
$lang['email']      = 'E-mail';
$lang['register']   = 'Zarejestruj się!';
$lang['profile']    = 'Profil użytkownika';
$lang['badlogin']   = 'Nazwa użytkownika lub hasło są nieprawidłowe.';
$lang['minoredit']  = 'Mniejsze zmiany';

$lang['regmissing'] = 'Wypełnij wszystkie pola.';
$lang['reguexists'] = 'Użytkownik o tej nazwie już istnieje.';
$lang['regsuccess'] = 'Utworzono użytkownika. Hasło zostało przesłane pocztą.';
$lang['regsuccess2']= 'Utworzono użytkownika.';
$lang['regmailfail']= 'Wystąpił błąd przy wysyłaniu hasła pocztą!';
$lang['regbadmail'] = 'Adres e-mail jest nieprawidłowy!';
$lang['regbadpass'] = 'Hasła nie są identyczne, spróbuj ponownie.';
$lang['regpwmail']  = 'Twoje hasło do DokuWiki';
$lang['reghere']    = 'Nie masz jeszcze konta? Zdobądź je';

$lang['profna']       = 'To wiki nie pozwala na zmianę profilu.';
$lang['profnochange'] = 'Żadnych zmian, nic do zrobienia.';
$lang['profnoempty']  = 'Pusta nazwa lub adres e-mail nie dozwolone.';
$lang['profchanged']  = 'Zaktualizowano profil użytkownika.';

$lang['pwdforget'] = 'Nie pamiętasz hasła? Zdobądź nowe!';
$lang['resendna']  = 'To wiki nie pozwala na powtórne przesyłanie hasła.';
$lang['resendpwd'] = 'Prześlij nowe hasło dla';
$lang['resendpwdmissing'] = 'Wypełnij wszystkie pola.';
$lang['resendpwdnouser']  = 'Nie można znaleźć tego użytkownika w bazie danych.';
$lang['resendpwdsuccess'] = 'Hasło zostało przesłane pocztą.';

$lang['txt_upload']   = 'Wybierz plik do wysłania';
$lang['txt_filename'] = 'Nazwa pliku (opcjonalnie)';
$lang['txt_overwrt']  = 'Nadpisać istniejący plik?';
$lang['lockedby']     = 'Aktualnie zablokowane przez';
$lang['lockexpire']   = 'Blokada wygasa';
$lang['willexpire']   = 'Za minutę Twoja blokada tej strony wygaśnie.\nW celu uniknięcia konfliktów wyświetl podgląd aby odnowić blokadę.';

$lang['notsavedyet'] = 'Nie zapisane zmiany zostaną utracone.\nCzy na pewno kontynuować?';
$lang['rssfailed']   = 'Wystąpił błąd przy pobieraniu tych danych: ';
$lang['nothingfound']= 'Nic nie znaleziono.';

$lang['mediaselect'] = 'Wysyłanie pliku';
$lang['fileupload']  = 'Wysyłanie pliku';
$lang['uploadsucc']  = 'Wysyłanie powiodło się!';
$lang['uploadfail']  = 'Błąd wysyłania pliku. Czy prawa do katalogów są poprawne?';
$lang['uploadwrong'] = 'Wysyłanie zabronione. Nie można wysłać plików z takim rozszerzeniem';
$lang['uploadexist'] = 'Plik już istnieje, nie wykonano operacji.';
$lang['deletesucc']  = 'Plik "%s" został usunięty.';
$lang['deletefail']  = 'Plik "%s" nie został usunięty, sprawdź uprawnienia.';
$lang['mediainuse']  = 'Plik "%s" nie został usunięty, ponieważ jest używany.';
$lang['namespaces']  = 'Katalogi';
$lang['mediafiles']  = 'Dostępne pliki';

$lang['reference']   = 'Odnośniki do';
$lang['ref_inuse']   = 'Ten plik nie może być usunięty, ponieważ jest używany na następujących stronach:';
$lang['ref_hidden']  = 'Odnośniki mogą znajdować się na stronach, do których nie masz uprawnień.';

$lang['hits']       = 'trafień';
$lang['quickhits']  = 'Pasujące hasła';
$lang['toc']        = 'Spis treści';
$lang['current']    = 'aktualna';
$lang['yours']      = 'Twoja wersja';
$lang['diff']       = 'Pokaż różnicę między wersjami';
$lang['line']       = 'Linia';
$lang['breadcrumb'] = 'Ślad';
$lang['youarehere'] = 'Jesteś tutaj';
$lang['lastmod']    = 'ostatnio zmienione';
$lang['by']         = 'przez';
$lang['deleted']    = 'usunięto';
$lang['created']    = 'utworzono';
$lang['restored']   = 'przywrócono poprzednią wersję';
$lang['summary']    = 'Opis zmian';

$lang['mail_newpage'] = 'Strona dodana:';
$lang['mail_changed'] = 'Strona zmieniona:';

$lang['nosmblinks'] = 'Odnośniki do zasobów sieci Windows działają tylko w przeglądarce Internet Explorer.\n Możesz skopiować odnośnik.';

$lang['qb_alert']   = 'Wpisz tekst, który chcesz sformatować.\nBędzie on dołączony na koniec strony.';
$lang['qb_bold']    = 'Pogrubienie';
$lang['qb_italic']  = 'Pochylenie';
$lang['qb_underl']  = 'Podkreślenie';
$lang['qb_code']    = 'Kod źródłowy';
$lang['qb_strike']  = 'Przekreślenie';
$lang['qb_h1']      = 'Nagłówek 1 stopnia';
$lang['qb_h2']      = 'Nagłówek 2 stopnia';
$lang['qb_h3']      = 'Nagłówek 3 stopnia';
$lang['qb_h4']      = 'Nagłówek 4 stopnia';
$lang['qb_h5']      = 'Nagłówek 5 stopnia';
$lang['qb_link']    = 'Odnośnik wewnętrzny';
$lang['qb_extlink'] = 'Odnośnik zewnętrzny';
$lang['qb_hr']      = 'Linia pozioma';
$lang['qb_ol']      = 'Numeracja';
$lang['qb_ul']      = 'Wypunktowanie';
$lang['qb_media']   = 'Dodaj obrazek lub inny plik';
$lang['qb_sig']     = 'Wstaw podpis';
$lang['qb_smileys'] = 'Emotikony';
$lang['qb_chars']   = 'Znaki specjalne';

$lang['del_confirm']= 'Czy napewno usunąć?';
$lang['admin_register']= 'Dodawanie użytkownika';

$lang['spell_start'] = 'Sprawdź pisownię';
$lang['spell_stop']  = 'Zakończ sprawdzanie';
$lang['spell_wait']  = 'Proszę czekać...';
$lang['spell_noerr'] = 'Nie znaleziono błędów';
$lang['spell_nosug'] = 'Brak podpowiedzi';
$lang['spell_change']= 'Zmień';

$lang['metaedit']    = 'Edytuj metadane';
$lang['metasaveerr'] = 'Zapis metadanych nie powiódł się';
$lang['metasaveok']  = 'Metadane zapisano';
$lang['img_backto']  = 'Wróć do';
$lang['img_title']   = 'Tytuł';
$lang['img_caption'] = 'Nagłówek';
$lang['img_date']    = 'Data';
$lang['img_fname']   = 'Nazwa pliku';
$lang['img_fsize']   = 'Rozmiar';
$lang['img_artist']  = 'Fotograf';
$lang['img_copyr']   = 'Prawa autorskie';
$lang['img_format']  = 'Format';
$lang['img_camera']  = 'Aparat';
$lang['img_keywords']= 'Słowa kluczowe';

$lang['subscribe_success']  = 'Dodano %s do listy subskrypcji strony %s';
$lang['subscribe_error']    = 'Błąd przy dodawaniu %s do listy subskrypcji strony %s';
$lang['subscribe_noaddress']= 'Nie podałeś adresu e-mail przy rejestracji, nie możesz zostać dodany do listy subskrypcji.';
$lang['unsubscribe_success']= 'Usunięto %s z listy subskrypcji strony %s';
$lang['unsubscribe_error']  = 'Błąd przu usuwaniu %s z listy subskrypcji strony %s';

/* auth.class language support */
$lang['authmodfailed']   = 'Błąd uwierzytelnienia. Powiadom administratora tego wiki.';
$lang['authtempfail']    = 'Uwierzytelnienie użytkownika jest w tej chwili niemożliwe. Jeśli ta sytuacja się powtórzy, powiadom administratora tego wiki.';

//Setup VIM: ex: et ts=2 enc=utf-8 :
